==> sd-shared-web-3.1.3-sources.jar: systems/dennis/shared/controller/items/AbstractAddItemController.java <==
package systems.dennis.shared.controller.items;


import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;
import systems.dennis.shared.annotations.security.Secured;
import systems.dennis.shared.annotations.security.WithRole;
import systems.dennis.shared.controller.forms.Serviceable;
import systems.dennis.shared.controller.items.magic.MagicForm;
import systems.dennis.shared.entity.AbstractEntity;
import systems.dennis.shared.exceptions.ItemForAddContainsIdException;
import systems.dennis.shared.form.AbstractForm;

/**
 * An interface which adds possibility to add data
 * <p>
 * requires a service, to be processed, which is accessed threw the getService method.
 */
@RestController
@Secured
public interface AbstractAddItemController<DB_TYPE extends AbstractEntity, FORM extends AbstractForm> extends Serviceable, Transformable<DB_TYPE, FORM>, MagicForm<FORM> {

    /**
     * Performs add procedure
     *
     * @param form form object to add
     * @return an object which had been saved in DB with it's ID
     * @throws ItemForAddContainsIdException - this exception, means that object is tried to be updated instead of added. To devide add and edit is necessary as two different operations with different privileges
     */
    @PostMapping(value = "/add",  consumes = {"application/json", "application/json;charset=UTF-8"}, produces = {"application/json", "application/json;charset=UTF-8"})
    @ResponseBody
    @WithRole
    default ResponseEntity<FORM> add(@RequestBody FORM form) throws ItemForAddContainsIdException {
        validate(form, form.getId() != null);
        DB_TYPE savedModel = (DB_TYPE) getService().save(fromForm(form));
        afterSaveForm(form, savedModel);
        return ResponseEntity.ok(toForm((savedModel)));
    }

    default void afterSaveForm(FORM form, DB_TYPE model) {};



}

==> sd-shared-web-3.2-sources.jar: systems/dennis/shared/controller/items/AbstractAddItemController.java <==
package systems.dennis.shared.controller.items;


import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;
import systems.dennis.shared.annotations.security.Secured;
import systems.dennis.shared.annotations.security.WithRole;
import systems.dennis.shared.controller.forms.Serviceable;
import systems.dennis.shared.controller.items.magic.MagicForm;
import systems.dennis.shared.entity.AbstractEntity;
import systems.dennis.shared.exceptions.ItemForAddContainsIdException;
import systems.dennis.shared.form.AbstractForm;
import systems.dennis.shared.model.IDPresenter;

import java.io.Serializable;

/**
 * An interface which adds possibility to add data
 * <p>
 * requires a service, to be processed, which is accessed threw the getService method.
 */
@RestController
@Secured
public interface AbstractAddItemController<DB_TYPE extends IDPresenter<ID_TYPE>, FORM extends AbstractForm<ID_TYPE>, ID_TYPE extends Serializable> extends Serviceable<DB_TYPE, ID_TYPE>, Transformable<DB_TYPE, FORM>, MagicForm<FORM> {

    /**
     * Performs add procedure
     *
     * @param form form object to add
     * @return an object which had been saved in DB with it's ID
     * @throws ItemForAddContainsIdException - this exception, means that object is tried to be updated instead of added. To devide add and edit is necessary as two different operations with different privileges
     */
    @PostMapping(value = "/add",  consumes = {"application/json", "application/json;charset=UTF-8"}, produces = {"application/json", "application/json;charset=UTF-8"})
    @ResponseBody
    @WithRole
    default ResponseEntity<FORM> add(@RequestBody FORM form) throws ItemForAddContainsIdException {
        validate(form, form.getId() != null);
        DB_TYPE savedModel = (DB_TYPE) getService().save(fromForm(form));
        afterSaveForm(form, savedModel);
        return ResponseEntity.ok(toForm((savedModel)));
    }

    default void afterSaveForm(FORM form, DB_TYPE model) {};



}
